ExKeyValue class

————————————————————————————————————————————————————————————————————————————— general object Key Value. use example:

  • bottom sheet dialog
  • list dialog
  • etc.

Constructors

ExKeyValue({required dynamic key, required String value, Widget? icon, bool? isSelected})

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ Widget?
getter/setter pair
isSelected ↔ bool?
getter/setter pair
key ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited