ExRandom mixin

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alpha(int length, {AbstractRandomProvider provider = const DefaultRandomProvider()}) → String
Generates a random string of length with only alpha characters.
alphaNumeric(int length, {AbstractRandomProvider provider = const DefaultRandomProvider()}) → String
Generates a random string of length with alpha-numeric characters.
between(int from, int to, {AbstractRandomProvider provider = const DefaultRandomProvider()}) → int
Generates a random integer where from <= to inclusive where 0 <= from <= to <= 999999999999999
numeric(int length, {AbstractRandomProvider provider = const DefaultRandomProvider()}) → String
Generates a random string of length with only numeric characters.
randomMerge(String a, String b) → String
Merge a with b and shuffle.
string(int length, {int from = asciiStart, int to = asciiEnd, AbstractRandomProvider provider = const DefaultRandomProvider()}) → String
Generates a random string of length with characters between ascii from to to. Defaults to characters of ascii '!' to '~'.