MapX<K, V> extension

Extensions for Map.

on

Properties

hasOne → bool

Available on Map<K, V>, provided by the MapX extension

Returns true if length of this Map is 1.
no setter
isLengthEven → bool

Available on Map<K, V>, provided by the MapX extension

Whether length of this Map is even.
no setter
isLengthOdd → bool

Available on Map<K, V>, provided by the MapX extension

Whether length of this Map is odd.
no setter

Methods

ifEmpty(Map<K, V> value) → Map<K, V>

Available on Map<K, V>, provided by the MapX extension

Returns this Map if it's not empty, otherwise returns value.
toUnmodifiableMap() → Map<K, V>

Available on Map<K, V>, provided by the MapX extension

Creates an unmodifiable Map containing the entries of this Map.