VelocityXInkWellBuilder class

Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

make({Key? key}) → Widget
makeCentered({Key? key}) → Widget

Available on VxWidgetBuilder<Widget>, provided by the VxCenterBuilderExtension extension

Extension method to directly access Center with any Vx widget without wrapping or with dot operator.
mdDoubleClick({required FnBuilderCallback onDoubleClick}) → VelocityXInkWellBuilder
On clicking two times.
mdLongClick({required FnBuilderCallback onLongClick}) → VelocityXInkWellBuilder
On long pressing.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
splashColor(Color color) → VelocityXInkWellBuilder
Use to show a splash color when clicking on the widget.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited