VxColorExtension extension

on

Properties

getMaterialColorValues → Map<int, Color>

Available on Color, provided by the VxColorExtension extension

Get MaterialColor values from the current color
no setter
isTransparent → bool

Available on Color, provided by the VxColorExtension extension

whether the color is transparent or not
no setter
swatch → MaterialColor

Available on Color, provided by the VxColorExtension extension

Get the swatch of the color
no setter
withBrightness → Color

Available on Color, provided by the VxColorExtension extension

Get the color with brightness of the current color
no setter

Methods

materialColor() → MaterialColor

Available on Color, provided by the VxColorExtension extension

Returns a MaterialColor based on the current color.
toHex({bool leadingHashSign = true}) → String

Available on Color, provided by the VxColorExtension extension

Prefixes a hash sign if leadingHashSign is set to true and returns the hexadecimal string value of the color.