VxDrawer mixin

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

show(BuildContext context, {required Widget child, VxDrawerType type = VxDrawerType.left, bool showMask = true, bool autoHide = false}) → VoidCallback
showBottomNotification(BuildContext context, {required Widget child, bool showMask = false, bool autoHide = true}) → VoidCallback
showTopNotification(BuildContext context, {required Widget child, bool showMask = false, bool autoHide = true}) → VoidCallback