VxWeb3 mixin

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

generatePin({int digits = 6}) → String
generate 6 digit random pin
hexify(BigInt dec, {bool isWithPrefix = true}) → String
toEther({required BigInt fromWei, int decimals = 18}) → double
Unit conversion: wei -> ether
toGWei({required double fromEther, int decimals = 9}) → BigInt
Unit conversion:toGWei
toWei({required double fromEther, int decimals = 18}) → BigInt
Unit conversion:toWei