VxWidgetsExtension extension

on

Methods

asList() → List<Widget>

Available on Widget, provided by the VxWidgetsExtension extension

aspectRatio(double aspectRatio) → AspectRatio

Available on Widget, provided by the VxWidgetsExtension extension

Extension for aspectRatio with AspectRatio
backdropFilter({Key? key, ImageFilter? filter, double fuzzyDegree = 4}) → BackdropFilter

Available on Widget, provided by the VxWidgetsExtension extension

backgroundColor(Color? color) → DecoratedBox

Available on Widget, provided by the VxWidgetsExtension extension

Extension for coloring a widget with DecoratedBox
clipHalf({Clip clipBehavior = Clip.antiAlias}) → ClipPath

Available on Widget, provided by the VxWidgetsExtension extension

Extension for creating a half shape using VxHalfClipper
clipOval({Clip clipBehavior = Clip.antiAlias, CustomClipper<Rect>? clipper}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Extension for creating a oval shape using ClipOval
color(Color color, {Key? key}) → ColoredBox

Available on Widget, provided by the VxWidgetsExtension extension

Wrap widget with ColoredBox
constrainedBox(BoxConstraints constraints, {Key? key}) → ConstrainedBox

Available on Widget, provided by the VxWidgetsExtension extension

cornerRadius(double radius) → ClipRRect

Available on Widget, provided by the VxWidgetsExtension extension

Extension for adding a corner radius a widget with ClipRRect
disabled(bool disable) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

errorWidget(Object ex) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Widget to show exception
expand({Key? key, int flex = 1}) → Expanded

Available on Widget, provided by the VxWidgetsExtension extension

Extension for Expanded
fittedBox({Key? key, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, Clip clipBehavior = Clip.none}) → FittedBox

Available on Widget, provided by the VxWidgetsExtension extension

flexible({Key? key, int flex = 1}) → Flexible

Available on Widget, provided by the VxWidgetsExtension extension

Extension for Flexible
foregroundColor(Color color, {Key? key}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Wrap widget with VxFilter
hero(Object tag, {Key? key, CreateRectTween? createRectTween, HeroFlightShuttleBuilder? flightShuttleBuilder, HeroPlaceholderBuilder? placeholderBuilder, bool transitionOnUserGestures = false}) → Hero

Available on Widget, provided by the VxWidgetsExtension extension

hide({Key? key, bool isVisible = false, bool maintainSize = false}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Hides a widget
innerShadow({Key? key, double blur = 2.0, Color color = Colors.black38, Offset offset = const Offset(2, 2)}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Extension method for VxInnerShadow Widget
keepAlive() → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Extension for keepAlive
material({Key? key, MaterialType type = MaterialType.canvas, Duration animationDuration = kThemeAnimationDuration, bool borderOnForeground = true, BorderRadiusGeometry? borderRadius, Clip clipBehavior = Clip.none, Color? color, double elevation = 0.0, Color? shadowColor, ShapeBorder? shape, TextStyle? textStyle}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Extension method for Material Widget
popupMenu(MenuBuilderCallback menuBuilder, {Key? key, VxPopupMenuController? controller, Color arrowColor = const Color(0xFF4C4C4C), double arrowSize = 10.0, Color barrierColor = Colors.black12, double horizontalMargin = 10.0, double verticalMargin = 10.0, bool showArrow = true, VxClickType clickType = VxClickType.singleClick}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Popup Menu Extensions
positioned({double? top, double? bottom, double? left, double? right, double? height, double? width, bool isFilled = false}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Extension for Stack Positioned
preferredSize(Size size) → PreferredSize

Available on Widget, provided by the VxWidgetsExtension extension

Maybe often use this when you want to make your own AppBar or NavigationBar with your custom UI
safeArea({Key? key, EdgeInsets minimum = EdgeInsets.zero, bool maintainBottomViewPadding = false, bool top = true, bool bottom = true, bool left = true, bool right = true}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Extension method for SafeArea Widget
shaderMask({required Gradient gradient, Key? key, BlendMode blendMode = BlendMode.modulate}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Extension method for ShaderMask Widget
sliverToBoxAdapter({Key? key}) → SliverToBoxAdapter

Available on Widget, provided by the VxWidgetsExtension extension

stroke(double width, Color color, {bool isCircle = false}) → DecoratedBox

Available on Widget, provided by the VxWidgetsExtension extension

Extension for giving a stroke with DecoratedBox
tooltip(String message, {Key? key, Decoration? decoration, double? height, bool? preferBelow, EdgeInsetsGeometry? padding, TextStyle? textStyle, Duration? waitDuration, EdgeInsetsGeometry? margin}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Tooltip as accessibility
toSliverBox({Key? key}) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Extension method for SliverToBoxAdapter Widget
when(bool condition) → Widget

Available on Widget, provided by the VxWidgetsExtension extension

Uses when clause to render the widget only when the condition is true.